ledger.GeneralAccountBalances (General Account Balances) — amici1

# `ledger.GeneralAccountBalances` (General Account Balances)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.CharField: ref>`

- `<django.db.models.fields.IntegerField: seqno>`

- `<lino.utils.mldbc.fields.BabelCharField: name>`

- `<lino.core.choicelists.ChoiceListField: common_account>`

- `<django.db.models.fields.BooleanField: needs_partner>`

- `<django.db.models.fields.BooleanField: clearable>`

- `<lino.core.fields.PriceField: default_amount>`

- `<django.db.models.fields.BooleanField: sales_allowed>`

- `<django.db.models.fields.BooleanField: purchases_allowed>`

- `<django.db.models.fields.BooleanField: wages_allowed>`

- `<django.db.models.fields.BooleanField: taxes_allowed>`

- `<django.db.models.fields.BooleanField: clearings_allowed>`

- `<django.db.models.fields.BooleanField: bank_po_allowed>`

Detail fields

- `<Panel main_1 in lino.core.layouts.DetailLayout on lino_xl.lib.ledger.ui.Accounts>`

- `<Panel main_2 in lino.core.layouts.DetailLayout on lino_xl.lib.ledger.ui.Accounts>`

- `<Panel main_3 in lino.core.layouts.DetailLayout on lino_xl.lib.ledger.ui.Accounts>`

- Movements (MovementsByAccount) : Shows the ledger movements done on a given general account.

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- Create (submit_insert) : Create the record and open a detail window on it

- ⚇ (duplicate) : Duplicate this row.

- Detail (detail) : Open a detail window on this record.

- Merge (merge_row) : See `<lino.core.merge.MergeAction merge_row ('Merge')>`.

- Debts (due) : See `<lino.core.actions.ShowSlaveTable due ('Debts')>`.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (move_by_n) : Move this row N rows upwards or downwards.

- ▼ (move_down) : Exchange the seqno of this item and the next item.

- ▲ (move_up) : Exchange the seqno of this item and the previous item.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

Filter parameters

- `<django.db.models.fields.related.ForeignKey: start_period>`

- `<django.db.models.fields.related.ForeignKey: end_period>`

- `<lino.core.fields.DummyField object at 0x7fc81ce4a9b0>`

- `<lino.core.fields.DummyField object at 0x7fc81ce4a9e8>`

- `<lino.core.choicelists.ChoiceListField: common_account>`

## Filter parameters